@@ -1,12 +1,12 @@
 package Net::SNTP::Client;
 
-use strict;
-use warnings;
-
 ## Validate the version of Perl
 
 BEGIN { die 'Perl version 5.6.0 or greater is required' if ($] < 5.006); }
 
+use strict;
+use warnings;
+
 =head1 NAME
 
 Net::SNTP::Client - Perl module to calculate the roundtrip delay d and
@@ -15,13 +15,13 @@ Net::SNTP::Client - Perl module to calculate the roundtrip delay d and
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
 ## Version of the Net::SNTP::Client module
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
     $VERSION = eval $VERSION;
 
 ## Load our modules
@@ -33,8 +33,8 @@ use Time::HiRes qw( gettimeofday );
 ## Handle importing/exporting of symbols
 
 use base qw( Exporter );
-our @ISA         = qw ( Exporter );
-our @EXPORT      = qw ( getSNTPTime );
+our @ISA        = qw ( Exporter );
+our @EXPORT_OK  = qw ( getSNTPTime );
 
 =head1 SYNOPSIS
 
@@ -43,6 +43,11 @@ The Net::SNTP::Client - Perl module retrieves the time from an NTP server
  clock offset t based on RFC4330. The module is calculating with higher
  accuracy in comparison to other modules.
 
+    use Net::SNTP::Client qw ( getSNTPTime );
+
+    my ( $error , $hashRefOutput ) = getSNTPTime( %hashInput );
+    ...
+
 
 =head1 ABSTRACT
 
@@ -96,7 +101,7 @@ This module exports a single method - getSNTPTime and an error
 
 =item * RFC4330 OUTPUT
 
-    -RFC4330: This is an optional way to produce an easy visuable
+    -RFC4330: This is an optional way to produce an easy visual
     output based on RFC4330 documentation.
 
 
@@ -515,7 +520,7 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =head1 CHANGE LOG
 $Log: Client.pm,v $
-Revision 5.0  2015/07/11 1:53:31  Thanos
+Revision 6.0  2015/07/11 5:43:31  Thanos
 
 
 =cut
